VegZ Analysis Report

# VegZ Vegetation Analysis Report

Generated: 2025-09-24 10:49:19

## Diversity Summary

Analysis completed successfully.

- mean_shannon: 1.914
- mean_simpson: 0.682
- total_species: 15.000
- total_sites: 30.000

## Ordination Summary

Analysis completed successfully.

- method: PCA
- variance_explained: [0.35, 0.25]

## Data Shape

Analysis completed successfully.

Report generated by VegZ - A comprehensive Python package for vegetation data analysis